==> minimalist-2.5.1.tgz: minimalist-2.5.1/contrib/languages/RU-addon.pl <==
push (@languages, 'ru');

##################################################################
###   ru = Russian

#-------------------------------
$msgtxt{'1ru'} = <<_EOF_ ;
This is the Minimalist Mailing List Manager.

        (   ), 
    (   ,     ). 
       ,    
,    'body' ( ).  
     'stop'  'exit' ( ),  
 10  .

  :

subscribe <list> [<email>] :
        <list>.   <list> 
     '-writers',      <list>,  
      ,    .

unsubscribe <list> [<email>] :
       <list>.     
    '-writers' (   . )

auth <code> :
      .    
       ,        
    .

mode <list> <email> <mode> :
           
     .     
    .   'mode'    
    (  ):
      * 'reader' -       ;
      * 'writer' -       
                        ;
      * 'usual' -       . 
		      
		  .
      * 'suspend' -    
      * 'resume' -    
      * 'maxsize <size>' -     (
			   ),   
			      .
      * 'reset' -    .
    
suspend <list>:
        

resume <list>:
        'suspend'  
     

maxsize <list> <size>:
        ( ),  
        .

which [<email>] :
       ,    

info [<list>] :
           
      <list>

who <list> :
         <list>

help :
       ( )

 ,  <email>      'who'  'mode'
     (, 
,   auth   
).      .  
         :

*password: list_password

      .    
    ,     
 .
_EOF_

#-------------------------------
$msgtxt{'2ru'} = ":\n\t";
$msgtxt{'3ru'} = "    .\n\n".
		 " :\n\t   ";
$msgtxt{'4ru'} = " \n\t'help' ( )     ,  .\n\n".
		 "   :";
#-------------------------------
$msgtxt{'5ru'} = ":\n\t       .\n\n".
		 "   :";
#-------------------------------
$msgtxt{'6ru'} = ":\n\t      (";
$msgtxt{'7ru'} = ").\n\n :\n\t   ,   ,\n\t    .\n\n".
		 "===========================================================================\n".
		 "   :";
#-------------------------------
$msgtxt{'8ru'} = "\n:\n\t        : ";
$msgtxt{'9ru'} = "\n\n :\n\t,     .\n";

#-------------------------------
$msgtxt{'10ru'} = "\n:\n\t     ,     .\n".
		  "\n :\n\t,      :)";
#-------------------------------
$msgtxt{'11ru'} = "\n      ";
#-------------------------------
$msgtxt{'12ru'} = "\n:\n\t    ";
$msgtxt{'13ru'} = ".\n\n :\n\t   ";
$msgtxt{'14ru'} = " \n\t'info' ( )      .\n";
#-------------------------------
$msgtxt{'15ru'} = "\n:\n\t         .\n".
		  "\n :\n\t,      :)";
#-------------------------------
$msgtxt{'16ru'} = "\n:\n\t,         .\n".
		  "\n :\n\t ,   ?      ";
#-------------------------------
$msgtxt{'17ru'} = "\n:\n\t,        .\n".
		  "\n :\n\t ,   ?      ";
#-------------------------------
$msgtxt{'18ru'} = " ";
$msgtxt{'19ru'} = "  .        ";
$msgtxt{'20ru'} = "(    'Reply'    )\n  :";
$msgtxt{'21ru'} = "     ";
$msgtxt{'22ru'} = "     .     \n .\n";
#-------------------------------
$msgtxt{'23ru'} = "\n     ";
#-------------------------------
$msgtxt{'24ru'} = "\n      ";
#-------------------------------
$msgtxt{'25ru'} = "\n ,  ";
$msgtxt{'25.1ru'} = "\n : ";
#-------------------------------
$msgtxt{'26ru'} = "\n:\n\t     ,    .";
#-------------------------------
$msgtxt{'27ru'} = "\n:\n\t     .\n\n :\n\n".$msgtxt{'1ru'};
#-------------------------------
$msgtxt{'28ru'} = "Sincerely, the Minimalist";
#-------------------------------
$msgtxt{'29ru'} = "     ";
#-------------------------------
$msgtxt{'30ru'} = " ,       (";
#-------------------------------
$msgtxt{'31ru'} = "    ";
$msgtxt{'32ru'} = ".\n\n,    :\n";
#-------------------------------
$msgtxt{'33ru'} = "     ";
$msgtxt{'34ru'} = "  ";
$msgtxt{'35ru'} = "      , ,   \n ";
#-------------------------------
$msgtxt{'36ru'} = "\n ";
$msgtxt{'37ru'} = "   .\n";
#-------------------------------
$msgtxt{'38ru'} = "\n   ;   .".
		  "\n,  ,    ";
$msgtxt{'38.1ru'} = "      ";
#-------------------------------
$msgtxt{'39ru'} = "       .\n";
#-------------------------------
$msgtxt{'40ru'} = "\n(-)";
#-------------------------------
$msgtxt{'41ru'} = "\n    ";
$msgtxt{'42ru'} = "   ";
$msgtxt{'43ru'} = "  ";
$msgtxt{'43.1ru'} = "  ";
$msgtxt{'43.2ru'} = "   ";
$msgtxt{'43.3ru'} = "  ";
$msgtxt{'43.4ru'} = "    (): ";
#-------------------------------
$msgtxt{'44ru'} = "\n:\n\t         .\n".
		  "\n:\n\t.";

==> minimalist-2.5.2.3.tgz: minimalist-2.5.2.3/contrib/languages/RU-addon.pl <==
push (@languages, 'ru');

##################################################################
###   ru = Russian

#-------------------------------
$msgtxt{'1ru'} = <<_EOF_ ;
This is the Minimalist Mailing List Manager.

        (   ), 
    (   ,     ). 
       ,    
,    'body' ( ).  
     'stop'  'exit' ( ),  
 10  .

  :

subscribe <list> [<email>] :
        <list>.   <list> 
     '-writers',      <list>,  
      ,    .

unsubscribe <list> [<email>] :
       <list>.     
    '-writers' (   . )

auth <code> :
      .    
       ,        
    .

mode <list> <email> <mode> :
           
     .     
    .   'mode'    
    (  ):
      * 'reader' -       ;
      * 'writer' -       
                        ;
      * 'usual' -       . 
		      
		  .
      * 'suspend' -    
      * 'resume' -    
      * 'maxsize <size>' -     (
			   ),   
			      .
      * 'reset' -    .
    
suspend <list>:
        

resume <list>:
        'suspend'  
     

maxsize <list> <size>:
        ( ),  
        .

which [<email>] :
       ,    

info [<list>] :
           
      <list>

who <list> :
         <list>

help :
       ( )

 ,  <email>      'who'  'mode'
     (, 
,   auth   
).      .  
 ,     ,   :

{pwd: list_password}

:

To: MML Discussion {pwd: password1235} <mml-general\@kiev.sovam.com>

       ,   
   .
_EOF_

#-------------------------------
$msgtxt{'2ru'} = ":\n\t";
$msgtxt{'3ru'} = "    .\n\n".
		 " :\n\t   ";
$msgtxt{'4ru'} = " \n\t'help' ( )     ,  .\n\n".
		 "   :";
#-------------------------------
$msgtxt{'5ru'} = ":\n\t       .\n\n".
		 "   :";
#-------------------------------
$msgtxt{'6ru'} = ":\n\t      (";
$msgtxt{'7ru'} = ").\n\n :\n\t   ,   ,\n\t    .\n\n".
		 "===========================================================================\n".
		 "   :";
#-------------------------------
$msgtxt{'8ru'} = "\n:\n\t        : ";
$msgtxt{'9ru'} = "\n\n :\n\t,     .\n";

#-------------------------------
$msgtxt{'10ru'} = "\n:\n\t     ,     .\n".
		  "\n :\n\t,      :)";
#-------------------------------
$msgtxt{'11ru'} = "\n      ";
#-------------------------------
$msgtxt{'12ru'} = "\n:\n\t    ";
$msgtxt{'13ru'} = ".\n\n :\n\t   ";
$msgtxt{'14ru'} = " \n\t'info' ( )      .\n";
#-------------------------------
$msgtxt{'15ru'} = "\n:\n\t         .\n".
		  "\n :\n\t,      :)";
#-------------------------------
$msgtxt{'16ru'} = "\n:\n\t,         .\n".
		  "\n :\n\t ,   ?      ";
#-------------------------------
$msgtxt{'17ru'} = "\n:\n\t,        .\n".
		  "\n :\n\t ,   ?      ";
#-------------------------------
$msgtxt{'18ru'} = " ";
$msgtxt{'19ru'} = "  .        ";
$msgtxt{'20ru'} = "(    'Reply'    )\n  :";
$msgtxt{'21ru'} = "     ";
$msgtxt{'22ru'} = "     .     \n .\n";
#-------------------------------
$msgtxt{'23ru'} = "\n     ";
#-------------------------------
$msgtxt{'24ru'} = "\n      ";
#-------------------------------
$msgtxt{'25ru'} = "\n ,  ";
$msgtxt{'25.1ru'} = "\n : ";
#-------------------------------
$msgtxt{'26ru'} = "\n:\n\t     ,    .";
#-------------------------------
$msgtxt{'27.0ru'} = "     ";
$msgtxt{'27ru'} = "\n:\n\t".$msgtxt{'27.0ru'}.".\n\n :\n\n".$msgtxt{'1ru'};
#-------------------------------
$msgtxt{'28ru'} = "Sincerely, the Minimalist";
#-------------------------------
$msgtxt{'29ru'} = "     ";
#-------------------------------
$msgtxt{'30ru'} = " ,       (";
#-------------------------------
$msgtxt{'31ru'} = "    ";
$msgtxt{'32ru'} = ".\n\n,    :\n";
#-------------------------------
$msgtxt{'33ru'} = "     ";
$msgtxt{'34ru'} = "  ";
$msgtxt{'35ru'} = "      , ,   \n ";
#-------------------------------
$msgtxt{'36ru'} = "\n ";
$msgtxt{'37ru'} = "   .\n";
#-------------------------------
$msgtxt{'38ru'} = "\n   ;   .".
		  "\n,  ,    ";
$msgtxt{'38.1ru'} = "      ";
#-------------------------------
$msgtxt{'39ru'} = "       .\n";
#-------------------------------
$msgtxt{'40ru'} = "\n(-)";
#-------------------------------
$msgtxt{'41ru'} = "\n    ";
$msgtxt{'42ru'} = "   ";
$msgtxt{'43ru'} = "  ";
$msgtxt{'43.1ru'} = "  ";
$msgtxt{'43.2ru'} = "   ";
$msgtxt{'43.3ru'} = "  ";
$msgtxt{'43.4ru'} = "    (): ";
#-------------------------------
$msgtxt{'44ru'} = "\n:\n\t         .\n".
		  "\n:\n\t.";
